==> repoze.retry-1.1.tar.gz: repoze.retry-1.1/setup.py <==
__version__ = '1.1'

import os
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.txt')).read()
CHANGES = open(os.path.join(here, 'CHANGES.txt')).read()

testing_extras = ['nose', 'coverage']

setup(name='repoze.retry',
      version=__version__,
      description='Middleware which implements a retryable exceptions',
      long_description=README + '\n\n' + CHANGES,
      classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: WSGI",
        "Topic :: Internet :: WWW/HTTP :: WSGI :: Middleware",
        ],
      keywords='wsgi middleware retry',
      author="Agendaless Consulting",
      author_email="repoze-dev@lists.repoze.org",
      url="http://www.repoze.org",
      license="BSD-derived (http://www.repoze.org/LICENSE.txt)",
      packages=find_packages(),
      include_package_data=True,
      namespace_packages=['repoze'],
      zip_safe=False,
      install_requires=['setuptools'],
      test_suite = "repoze.retry.tests",
      tests_require=[
        'wsgiref',
      ],
      entry_points="""
      [paste.filter_app_factory]
      retry = repoze.retry:make_retry
      """,
      extras_require = {
        'testing': testing_extras,
      }
)

==> repoze.retry-1.2.tar.gz: repoze.retry-1.2/setup.py <==
__version__ = '1.2'

import os
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.txt')).read()
CHANGES = open(os.path.join(here, 'CHANGES.txt')).read()

testing_extras = ['nose', 'coverage']

setup(name='repoze.retry',
      version=__version__,
      description='Middleware which implements a retryable exceptions',
      long_description=README + '\n\n' + CHANGES,
      classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: WSGI",
        "Topic :: Internet :: WWW/HTTP :: WSGI :: Middleware",
        ],
      keywords='wsgi middleware retry',
      author="Agendaless Consulting",
      author_email="repoze-dev@lists.repoze.org",
      url="http://www.repoze.org",
      license="BSD-derived (http://www.repoze.org/LICENSE.txt)",
      packages=find_packages(),
      include_package_data=True,
      namespace_packages=['repoze'],
      zip_safe=False,
      install_requires=['setuptools'],
      test_suite = "repoze.retry.tests",
      tests_require=[
        'wsgiref',
      ],
      entry_points="""
      [paste.filter_app_factory]
      retry = repoze.retry:make_retry
      """,
      extras_require = {
        'testing': testing_extras,
      }
)
